@@ -278,6 +278,16 @@ void grab_default_ppd(GtkWidget * menu_item, gpointer ppd)
     fclose(psconfig);
   }
 
+  if(local_ppd->spooler==SPOOLER_CUPS && default_ppd_file == NULL) {
+    default_ppd_file=g_strconcat("/etc/cups/ppd/",local_ppd->printer_name,".ppd",NULL);
+    struct stat buf;
+    if ( 0!=stat(default_ppd_file, &buf ) ) {      
+      g_warning("PPD not found in usual CUPS place: %s \n",default_ppd_file);
+      g_free( default_ppd_file);
+      default_ppd_file=NULL;
+    }
+  }
+
   /* Check the local default after looking for the "global" default */
   user_ppd_path = g_strconcat(local_ppd->config_dir, "/ppd.conf", NULL);
   user_ppd = fopen((char *)user_ppd_path, "r");
@@ -694,7 +704,8 @@ void send_print(GtkWidget * button, gpointer ppd)
     quoted_filename[b++]='\'';
   }
 
-  if (g_strcasecmp(local_ppd->ppd_file, local_ppd->default_ppd_file)
+  if (local_ppd->ppd_file && local_ppd->default_ppd_file &&
+      g_strcasecmp(local_ppd->ppd_file, local_ppd->default_ppd_file)
       == 0)
     is_sys_def_ppd = 1;
 
@@ -807,14 +818,10 @@ void send_print(GtkWidget * button, gpointer ppd)
 
       /* Will support more spoolers in future */
       switch (local_ppd->spooler) {
-      case 1:			/* LPRng */
+      case SPOOLER_LPRNG:			/* LPRng */
 	command_line =
 	  g_strconcat(command_line, "-Z ", current_option, " ", NULL);
 	break;
-      case 0:			/* lpr */
-	command_line =
-	  g_strconcat(command_line, "-o ", current_option, " ", NULL);
-	break;
       default:
 	command_line =
 	  g_strconcat(command_line, "-o ", current_option, " ", NULL);
@@ -1672,12 +1679,9 @@ void update_num_copies(GtkSpinButton * spinbutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     copy_command = g_strdup("-Z copies:");
     break;
-  case 0:			/* lpr */
-    copy_command = g_strdup("-o copies:");
-    break;
   default:
     copy_command = g_strdup("-o copies:");
     break;
@@ -1719,12 +1723,9 @@ void update_pageset_odd(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->page_set = g_strdup("-Z page-set:odd");
     break;
-  case 0:			/* lpr */
-    local_ppd->page_set = g_strdup("-o page-set:odd");
-    break;
   default:
     local_ppd->page_set = g_strdup("-o page-set:odd");
     break;
@@ -1745,12 +1746,9 @@ void update_pageset_even(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->page_set = g_strdup("-Z page-set:even");
     break;
-  case 0:			/* lpr */
-    local_ppd->page_set = g_strdup("-o page-set:even");
-    break;
   default:
     local_ppd->page_set = g_strdup("-o page-set:even");
     break;
@@ -1787,16 +1785,11 @@ void update_range_from(GtkWidget * entrybox, gpointer ppd)
   else {
     /* Will support more spoolers in future */
     switch (local_ppd->spooler) {
-    case 1:			/* LPRng */
+    case SPOOLER_LPRNG:			/* LPRng */
       range =
 	g_strconcat("-Z page-ranges:", local_ppd->range_from, "-",
 		    local_ppd->range_to, NULL);
       break;
-    case 0:			/* lpr */
-      range =
-	g_strconcat("-o page-ranges:", local_ppd->range_from, "-",
-		    local_ppd->range_to, NULL);
-      break;
     default:
       range =
 	g_strconcat("-o page-ranges:", local_ppd->range_from, "-",
@@ -1836,16 +1829,11 @@ void update_range_to(GtkWidget * entrybox, gpointer ppd)
 
     /* Will support more spoolers in future */
     switch (local_ppd->spooler) {
-    case 1:			/* LPRng */
+    case SPOOLER_LPRNG:			/* LPRng */
       range =
 	g_strconcat("-Z page-ranges:", local_ppd->range_from, "-",
 		    local_ppd->range_to, NULL);
       break;
-    case 0:			/* lpr */
-      range =
-	g_strconcat("-o page-ranges:", local_ppd->range_from, "-",
-		    local_ppd->range_to, NULL);
-      break;
     default:
       range =
 	g_strconcat("-o page-ranges:", local_ppd->range_from, "-",
@@ -1869,12 +1857,9 @@ void update_collate_yes(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->collate = g_strdup("-Z Collate:true");
     break;
-  case 0:			/* lpr */
-    local_ppd->collate = g_strdup("-o Collate:true");
-    break;
   default:
     local_ppd->collate = g_strdup("-o Collate:true");
     break;
@@ -1906,12 +1891,9 @@ void update_revordr_yes(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->output_order = g_strdup("-Z OutputOrder:reverse");
     break;
-  case 0:			/* lpr */
-    local_ppd->output_order = g_strdup("-o OutputOrder:reverse");
-    break;
   default:
     local_ppd->output_order = g_strdup("-o OutputOrder:reverse");
     break;
@@ -1955,12 +1937,9 @@ void update_nup_2up(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->n_up = g_strdup("-Z number-up:2");
     break;
-  case 0:			/* lpr */
-    local_ppd->n_up = g_strdup("-o number-up:2");
-    break;
   default:
     local_ppd->n_up = g_strdup("-o number-up:2");
     break;
@@ -1979,12 +1958,9 @@ void update_nup_4up(GtkWidget * radiobutton, gpointer ppd)
 
   /* Will support more spoolers in future */
   switch (local_ppd->spooler) {
-  case 1:			/* LPRng */
+  case SPOOLER_LPRNG:			/* LPRng */
     local_ppd->n_up = g_strdup("-Z number-up:4");
     break;
-  case 0:			/* lpr */
-    local_ppd->n_up = g_strdup("-o number-up:4");
-    break;
   default:
     local_ppd->n_up = g_strdup("-o number-up:4");
     break;
