@@ -1574,6 +1574,25 @@ GtkWidget *create_constraint_messagebox(gchar * message)
   return constraint_messagebox;
 }
 
+int get_spooler_type_debian(void)
+{
+  struct stat buf;
+  if ( 0==stat("/usr/share/doc/cupsys-bsd", &buf ) ) {
+    return  SPOOLER_CUPS;
+  }
+  if ( 0==stat("/usr/share/doc/lprng", &buf ) ) {
+    return  SPOOLER_LPRNG;
+  }
+  if ( 0==stat("/usr/share/doc/lpr", &buf ) ) {
+    return  SPOOLER_LPR;
+  }
+  if ( 0==stat("/usr/share/doc/lpr-ppd", &buf ) ) {
+    return  SPOOLER_LPR;
+  }
+  return SPOOLER_UNKNOWN;
+  
+}
+
 
 /*----------------------------------------------------------------
   LPRng can be distinguished from lpr by their respective 
@@ -1581,8 +1600,10 @@ GtkWidget *create_constraint_messagebox(gchar * message)
   It would be nice if we could distinguish (via lpr) if it was 
   the hacked (-o) version or unhacked, but so far I've had no 
   luck. <-mpruett>
+
+  Not anymore... this code is useless since nowadays the output is localized <Mennucc>
 ----------------------------------------------------------------*/
-int get_spooler_type(void)
+int get_spooler_type_obsolete(void)
 {
   FILE *fp;
   char buf[81];
@@ -1732,7 +1753,7 @@ static GtkWidget *get_printer_menu(ppd_struct * ppd)
 	continue;
       else {
 	/* See if this entry is a spool_directory. */
-	spool_dir = strstr(curr_line, ":sd");
+	spool_dir = strstr(curr_line, ":sd=");
 	if (spool_dir != NULL) {
 	  spool_dir = spool_dir + 4;	/* move 4 spaces to the right */
 	  end = strchr(spool_dir, ':');
@@ -1759,16 +1780,28 @@ before the newline. gpr may have failed in parsing your /etc/printcap");
 	  gtk_object_set_data(GTK_OBJECT(current_printer_item), SD,
 			      g_strdup(spool_dir));
 	} else {
-	  strcpy(targetstr, ":ppdfile");
+	  strcpy(targetstr, ":ppdfile=");
 	  ppdfile = strstr(curr_line, targetstr);
 	  if (ppdfile) {
-	    ppdfile = ppdfile + strlen(targetstr) + 1;
+	    ppdfile = ppdfile + strlen(targetstr);
 	    end = strchr(ppdfile, ':');
 	    if(end)
 	      end[0] = '\0';
 
 	    gtk_object_set_data(GTK_OBJECT(current_printer_item), PF,
 				g_strdup(ppdfile));
+	  } else {
+	    strcpy(targetstr, ":ppd=");
+	    ppdfile = strstr(curr_line, targetstr);
+	    if (ppdfile) {
+	      ppdfile = ppdfile + strlen(targetstr);
+	      end = strchr(ppdfile, ':');
+	      if(end)
+		end[0] = '\0';
+	      
+	      gtk_object_set_data(GTK_OBJECT(current_printer_item), PF,
+				  g_strdup(ppdfile));
+	    }
 	  }
 	}
 
